==> bloodhound_8.1.0.orig.tar.gz: BloodHound-8.1.0/packages/javascript/bh-shared-ui/src/components/HelpTexts/AZWebsiteContributor/References.tsx <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

import { Box, Link } from '@mui/material';
import { FC } from 'react';

const References: FC = () => {
    return (
        <Box sx={{ overflowX: 'auto' }}>
            <Link target='_blank' rel='noopener' href='https://github.com/BloodHoundAD/BARK'>
                Andy Robbins - BARK.ps1
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener'
                href='https://www.netspi.com/blog/technical/cloud-penetration-testing/lateral-movement-azure-app-services/'>
                Karl Fosaaen - Lateral Movement in Azure App Services
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener'
                href='https://posts.specterops.io/abusing-azure-app-service-managed-identity-assignments-c3adefccff95'>
                Andy Robbins - Abusing Azure App Service Managed Identity Assignments
            </Link>
        </Box>
    );
};

export default References;

==> bloodhound_8.3.1.orig.tar.gz: BloodHound-8.3.1/packages/javascript/bh-shared-ui/src/components/HelpTexts/AZWebsiteContributor/References.tsx <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

import { Box, Link } from '@mui/material';
import { FC } from 'react';

const References: FC = () => {
    return (
        <Box sx={{ overflowX: 'auto' }}>
            <Link target='_blank' rel='noopener noreferrer' href='https://github.com/BloodHoundAD/BARK'>
                Andy Robbins - BARK.ps1
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener noreferrer'
                href='https://www.netspi.com/blog/technical/cloud-penetration-testing/lateral-movement-azure-app-services/'>
                Karl Fosaaen - Lateral Movement in Azure App Services
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener noreferrer'
                href='https://posts.specterops.io/abusing-azure-app-service-managed-identity-assignments-c3adefccff95'>
                Andy Robbins - Abusing Azure App Service Managed Identity Assignments
            </Link>
        </Box>
    );
};

export default References;
